@@ -37,8 +37,9 @@ class Graph(object):
         visualization = TaskVisualization(task)
         self.write(visualization.details())
         self.write(visualization.links())
+        self.write(visualization.invoked())
 
-        for dependency in visualization.dependencys():
+        for dependency in visualization.dependencies():
             self.write(dependency.details())
 
     def __call__(self):
